@@ -3,7 +3,8 @@ BBoptim <- function(par, fn, gr=NULL, method=c(2,3,1),
      control=list(), quiet=FALSE, ...) 
     {
     ctrl <- list(maxit = 1500, M = c(50, 10), ftol=1.e-10, gtol = 1e-05, maxfeval = 10000, 
-        maximize = FALSE, trace = TRUE, triter = 10, eps = 1e-07, checkGrad=NULL)
+        maximize = FALSE, trace = TRUE, triter = 10, eps = 1e-07, checkGrad=NULL, 
+        checkGrad.tol=1.e-06)
     namc <- names(control)
     if (!all(namc %in% names(ctrl))) 
         stop("unknown names in control: ", namc[!(namc %in% names(ctrl))])
@@ -19,6 +20,7 @@ BBoptim <- function(par, fn, gr=NULL, method=c(2,3,1),
     triter <- ctrl$triter
     eps <- ctrl$eps
     checkGrad <- ctrl$checkGrad
+    checkGrad.tol <- ctrl$checkGrad.tol  
     control.pars <- expand.grid(method=method, M=M)
 
     feval <- iter <-  0
