@@ -32,7 +32,7 @@ sane <- function (par, fn, method = 2, control = list(),
             xnew <- x + lambda * sgn * F
             Fnew <- try(do.call(fn, append(list(xnew), fargs)))
             fcnt = fcnt + 1
-            if (class(Fnew) == "try-error" || any(is.nan(Fnew))) 
+            if (inherits(Fnew, "try-error") || any(is.nan(Fnew))) 
                 return(list(xnew = NA, Fnew = NA, fcnt = fcnt, 
                   bl = bl, lsflag = 1, fune = NA))
             else fune <- sum(Fnew * Fnew)
@@ -70,7 +70,7 @@ sane <- function (par, fn, method = 2, control = list(),
 ##  We do initial Nelder-Mead start-up
 	if (NM) {
 		res <- try(optim(par=par, fn=U, method="Nelder-Mead", control=list(maxit=100), ...), silent=TRUE)
-		if (class(res) == "try-error") { 
+		if (inherits(res, "try-error")) { 
 			cat(res)
 			stop("\nFailure in Nelder-Mead Start.  Try another starting value \n")
 			}
@@ -82,7 +82,7 @@ sane <- function (par, fn, method = 2, control = list(),
 
     F <- try(fn(par, ...))
 	fcnt <- fcnt + 1
-    if (class(F) == "try-error") 
+    if (inherits(F, "try-error"))
         stop(" Failure in initial functional evaluation.")
     else if (!is.numeric(F) || !is.vector(F)) 
         stop("Function must return a vector numeric value.")
@@ -103,7 +103,7 @@ sane <- function (par, fn, method = 2, control = list(),
     while (normF/sqrt(n) > tol & iter <= maxit) {
         Fa <- try(fn(par + h * F, ...))
         fcnt <- fcnt + 1
-        if (class(Fa) == "try-error" || any(is.nan(Fa))) {
+        if (inherits(Fa, "try-error") || any(is.nan(Fa))) {
             flag <- 1
             break
         }
