@@ -115,7 +115,7 @@ spg <- function(par, fn, gr=NULL, method=3, lower=-Inf, upper=Inf,
 	 "See the help for spg to enable this.")
 	} 
 
-  if (class(f)=="try-error" )
+  if (inherits(f, "try-error"))
         stop("Failure in initial function evaluation!", f)
   else if ( !is.numeric(f) || 1 != length(f) )
         stop("function must return a scalar numeric value!")
@@ -136,7 +136,7 @@ spg <- function(par, fn, gr=NULL, method=3, lower=-Inf, upper=Inf,
     fnew <- try(do.call(func, append(list(pnew) , fargs )),silent=TRUE)
     feval <- feval + 1
  
-    if (class(fnew)=="try-error" | is.nan(fnew) )
+    if (inherits(fnew, "try-error") | is.nan(fnew) )
             return(list(p=NA, f=NA, feval=NA, lsflag=1))
  
     while(fnew > fmax + gamma*alpha*gtd) {
@@ -151,7 +151,7 @@ spg <- function(par, fn, gr=NULL, method=3, lower=-Inf, upper=Inf,
     	fnew <- try(do.call(func, append(list(pnew), fargs )), silent=TRUE)
     	feval <- feval + 1
  
-    	if (class(fnew)=="try-error" | is.nan(fnew) )
+    	if (inherits(fnew, "try-error") | is.nan(fnew) )
 	       return(list(p=NA, f=NA, feval=NA, lsflag=1))
     	if (feval > maxfeval)
 	       return(list(p=NA, f=NA, feval=NA, lsflag=2))
@@ -209,7 +209,7 @@ spg <- function(par, fn, gr=NULL, method=3, lower=-Inf, upper=Inf,
   if (prj){
      par <- try(do.call(project,  append(list(par), projectArgs)), silent=TRUE)
  
-     if (class(par) == "try-error") 
+     if (inherits(par, "try-error")) 
            stop("Failure in projecting initial guess!", par)
      }
   if (any(is.nan(par), is.na(par)) ) stop("Failure in initial guess!")
@@ -217,7 +217,7 @@ spg <- function(par, fn, gr=NULL, method=3, lower=-Inf, upper=Inf,
  
   g <- try(grad(par, ...),silent=TRUE)
  
-  if (class(g)=="try-error" ) 
+  if (inherits(g, "try-error"))
         stop("Failure in initial gradient evaluation!", g)
   else if (any(is.nan(g)) ) 
         stop("Failure in initial gradient evaluation!")
@@ -227,7 +227,7 @@ spg <- function(par, fn, gr=NULL, method=3, lower=-Inf, upper=Inf,
   pg <- par - g
   if (prj){
     pg <- try(do.call(project,  append(list(pg), projectArgs)),silent=TRUE)
-    if (class(pg)=="try-error" ) stop("Failure in initial projection!", pg)
+    if (inherits(pg, "try-error")) stop("Failure in initial projection!", pg)
     } 
     
   if (any(is.nan(pg))) stop("Failure in initial projection!")
@@ -251,7 +251,7 @@ spg <- function(par, fn, gr=NULL, method=3, lower=-Inf, upper=Inf,
    d <- par - lambda * g
    if (prj){
      d <- try(do.call(project,  append(list(d), projectArgs)), silent=TRUE)
-     if (class(d) == "try-error" | any(is.nan(d))  ) {
+     if (inherits(d, "try-error") | any(is.nan(d))  ) {
           lsflag <- 4
           break
           }
@@ -278,7 +278,7 @@ spg <- function(par, fn, gr=NULL, method=3, lower=-Inf, upper=Inf,
  
       gnew <- try(grad(pnew, ...),silent=TRUE)     
  
-      if (class(gnew)=="try-error" | any(is.nan(gnew)) ){
+      if (inherits(gnew, "try-error") | any(is.nan(gnew)) ){
         lsflag <- 3
         break
         }
@@ -305,7 +305,7 @@ spg <- function(par, fn, gr=NULL, method=3, lower=-Inf, upper=Inf,
       pg <- par - g
       if (prj){
         pg <- try(do.call(project, append(list(pg), projectArgs)), silent=TRUE)
-        if (class(pg) == "try-error" | any(is.nan(pg)) ) {
+        if (inherits(pg, "try-error") | any(is.nan(pg)) ) {
   	  lsflag <- 4
   	  break
   	  }
